@@ -5,7 +5,7 @@ from flask.ext.babel import gettext, ngettext, lazy_gettext
 from forms import GeneralModelConverter
 from .filemanager import uuid_originalname
 from .security.decorators import has_access
-from .widgets import FormWidget, ShowWidget, ListWidget, SearchWidget
+from .widgets import FormWidget, ShowWidget, ListWidget, SearchWidget, ListCarousel
 from .actions import ActionItem
 
 
@@ -24,11 +24,11 @@ def expose(url='/', methods=('GET',)):
         f._urls.append((url, methods))
         return f
     return wrap
-    
-    
+
+
 class BaseView(object):
     """
-        All views derive from this class. it's constructor will register your exposed urls on flask as a Blueprint.
+        All views inherit from this class. it's constructor will register your exposed urls on flask as a Blueprint.
 
         This class does not expose any urls, but provides a common base for all views.
         
@@ -222,10 +222,10 @@ class IndexView(BaseView):
 
 class SimpleFormView(BaseView):
     """
-        View for presenting you own forms
-        Derive from this view to provide some base processing for your costumized form views.
+        View for presenting your own forms
+        Inherit from this view to provide some base processing for your costumized form views.
 
-        Notice that this class derives from BaseView so all properties from the parent class can be overrided also.
+        Notice that this class inherits from BaseView so all properties from the parent class can be overrided also.
 
         Implement form_get and form_post to implement your form pre-processing and post-processing
     """
@@ -339,11 +339,11 @@ class BaseCRUDView(BaseView):
 
     
     add_form = None
-    """ Your own add WTF form for Add """
+    """ To implement your own add WTF form for Add """
     edit_form = None
-    """ Your own add WTF form for Edit """
+    """ To implement your own add WTF form for Edit """
     search_form = None
-    """ Your own add WTF form for Search """
+    """ To implement your own add WTF form for Search """
 
     validators_columns = {}
 
@@ -533,42 +533,36 @@ class BaseCRUDView(BaseView):
         print self.__class__.__name__, "LIST COL", self.list_columns
 
     
-    @classmethod
     def pre_update(self, item):
         """
             Override this, will be called before update
         """
         pass
 
-    @classmethod
     def post_update(self, item):
         """
             Override this, will be called after update
         """        
         pass
 
-    @classmethod
     def pre_add(self, item):
         """
             Override this, will be called before add
         """        
         pass
 
-    @classmethod
     def post_add(self, item):
         """
             Override this, will be called after update
         """        
         pass
 
-    @classmethod
     def pre_delete(self, item):
         """
             Override this, will be called before delete
         """        
         pass
 
-    @classmethod
     def post_delete(self, item):
         """
             Override this, will be called after delete
@@ -576,12 +570,11 @@ class BaseCRUDView(BaseView):
         pass
 
 
-
 class GeneralView(BaseCRUDView):
     """
-        This is the most important view. If you want to automatically implement create, edit, delete, show, and search form your database tables, derive your views from this class.
+        This is the most important view. If you want to automatically implement create, edit, delete, show, and search form your database tables, inherit your views from this class.
 
-        Notice that this class derives from BaseView so all properties from the parent class can be overrided also.
+        Notice that this class inherits from BaseView so all properties from the parent class can be overrided also.
     """
 
     def __init__(self, **kwargs):
